@@ -5,7 +5,7 @@
 # Copyright reserved.  2018.
 # GPL License 3.0 or newer.
 # This is a program for filling a design space multivariate discrete dataseries
-# by creatinng recursive and progressive relations of linear interpolation.
+# by creatinng recursive and progressive relations by various strategies.
 use v5.14;
 use Math::Round;
 use List::Util qw[ min max reduce shuffle];
@@ -669,11 +669,11 @@ sub wei
 
 
   my $bank_ref = fillbank;
-  my %bank =  %{ $bank_ref }; say $tee "\%bank: " . dump( %bank );
+  #my %bank =  %{ $bank_ref }; say $tee "\%bank: " . dump( %bank );
 
 
   sub cyclearr
-  { say $tee "NOW IN CYCLEARR.";
+  { #say $tee "NOW IN CYCLEARR.";
     my $coun = 0;
     foreach my $el ( @arr )
     { #say $tee "\$el->[1]: " . dump( $el->[1] ); #say $tee "EL: " . dump( $el );
@@ -786,7 +786,7 @@ sub wei
                           my $soughtval = ( $elt->[2] + ( $elt->[2] * $soughtinc ) );
                           push ( @{ $wand{$key}{vals} }, $soughtval );
                           push ( @{ $wand{$key}{dists} }, $totdist );
-                          say $tee "PUSHING \$soughtval $soughtval INTO \@{ \$wand{\$key}{vals} }: " . dump( @{ $wand{\$key}{vals} } ) . " BECAUSE KEY: $key . " ;
+                          #say $tee "PUSHING \$soughtval $soughtval INTO \@{ \$wand{\$key}{vals} }: " . dump( @{ $wand{\$key}{vals} } ) . " BECAUSE KEY: $key . " ;
 
                           #my $strength = ( ( $elt->[3] ** $totstrength ) ** ( 1/2 ) );
 
@@ -796,20 +796,17 @@ sub wei
                           push ( @{ $wand{$key}{origin} }, $elt->[0] );
                           $wand{$key}{name} = $key;
                           $wand{$key}{bulk} = [ @{ $elt->[1] } ] ;
-                          say $tee "EXECUTING";
-                        }
-                        else
-                        {
-                          say $tee "NOT PUSHING INTO WAND ";
+                          #say $tee "EXECUTING";
                         }
+                        #else
+                        #{
+                        #  say $tee "NOT PUSHING INTO WAND ";
+                        #}
                       }
-                      else
-                      {
-                        say $tee "NOT WEIGHTVALS1ING ";
-                        #say $tee "\@boxgrads " . dump( @boxgrads );
-                        #say $tee "\@boxdists " . dump( @boxdists );
-                        #say $tee "\@boxors " . dump( @boxors );
-                      }
+                      #else
+                      #{
+                      #  say $tee "NOT WEIGHTVALS1ING ";
+                      #}
                     }
                   }
                   $co++
@@ -825,7 +822,7 @@ sub wei
 
 
   cyclearr;
-  say $tee "\%wand: " . dump( %wand );
+  #say $tee "\%wand: " . dump( %wand );
 
 
   my @limb0;
@@ -1404,7 +1401,7 @@ sub interlinear
                 #say $tee "OBTAINED2 \$totstrength: " . dump( $totstrength ) . "FOR " . dump( $elt->[0] ) ;
                 push ( @{ $elt }, $soughtval, $totstrength ); #say $tee "OBTAINED \$elt: " . dump( $elt ) . "LAST ";
               }
-              else { say $tee "CHECK! WRONG!"; }
+              #else { say $tee "CHECK! WRONG!"; }
             }
           }
         }
@@ -1438,7 +1435,7 @@ open( NEWFILE, ">$newfile" ) or die;
 foreach my $entry ( @arr )
 {
   my $coun = 0;
-  my $number = scalar( @{ $entry->[1] } User menu);
+  my $number = scalar( @{ $entry->[1] } );
   foreach my $item ( @{ $entry->[1] } )
   {
     if ( not ( $coun == $number ) )
